"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.default = void 0;

var _react = require("react");

var _core = require("@emotion/core");

var _dsExplorations = require("@atlaskit/ds-explorations");

var _colors = require("@atlaskit/theme/colors");

/* eslint-disable @atlaskit/design-system/ensure-design-token-usage */

/** @jsx jsx */

/**
 * __Lozenge__
 *
 * A lozenge is a visual indicator used to highlight an item's status for quick recognition.
 *
 * - [Examples](https://atlassian.design/components/lozenge/examples)
 * - [Code](https://atlassian.design/components/lozenge/code)
 * - [Usage](https://atlassian.design/components/lozenge/usage)
 */
var Lozenge = /*#__PURE__*/(0, _react.memo)(function (_ref) {
  var children = _ref.children,
      testId = _ref.testId,
      _ref$isBold = _ref.isBold,
      isBold = _ref$isBold === void 0 ? false : _ref$isBold,
      _ref$appearance = _ref.appearance,
      appearance = _ref$appearance === void 0 ? 'default' : _ref$appearance,
      _ref$maxWidth = _ref.maxWidth,
      maxWidth = _ref$maxWidth === void 0 ? 200 : _ref$maxWidth,
      _ref$style = _ref.style,
      style = _ref$style === void 0 ? {} : _ref$style;
  var appearanceStyle = isBold ? 'bold' : 'subtle';
  var appearanceType = appearance in backgroundColors[appearanceStyle] ? appearance : 'default';
  var maxWidthValue = typeof maxWidth === 'string' ? maxWidth : "".concat(maxWidth, "px");
  return (0, _core.jsx)(_dsExplorations.UNSAFE_Box, {
    as: "span",
    display: "inlineFlex",
    backgroundColor: backgroundColors[appearanceStyle][appearanceType],
    borderRadius: "normal",
    paddingInline: "sp-50",
    position: "static",
    testId: testId,
    UNSAFE_style: {
      backgroundColor: style.backgroundColor,
      verticalAlign: 'baseline',
      maxWidth: '100%'
    }
  }, (0, _core.jsx)(_dsExplorations.UNSAFE_Text, {
    as: "span",
    fontSize: "11px",
    fontWeight: "700",
    lineHeight: "16px",
    textTransform: "uppercase",
    color: textColors[appearanceStyle][appearanceType],
    shouldTruncate: true,
    UNSAFE_style: {
      color: style.color,
      width: '100%',
      maxWidth: "calc(".concat(maxWidthValue, " - ").concat(_dsExplorations.UNSAFE_SPACING_SCALE['sp-100'], "px)") // to negate paddingInline specified on Box above

    },
    testId: testId && "".concat(testId, "--text")
  }, children));
});
Lozenge.displayName = 'Lozenge';
var _default = Lozenge; // Lozenge colors

exports.default = _default;
var backgroundColors = {
  bold: {
    default: ['neutral.bold', _colors.N500],
    inprogress: ['information.bold', _colors.B400],
    moved: ['warning.bold', _colors.Y500],
    new: ['discovery.bold', _colors.P400],
    removed: ['danger.bold', _colors.R400],
    success: ['success.bold', _colors.G400]
  },
  subtle: {
    default: ['neutral', _colors.N40],
    inprogress: ['information', _colors.B50],
    moved: ['warning', _colors.Y75],
    new: ['discovery', _colors.P50],
    removed: ['danger', _colors.R50],
    success: ['success', _colors.G50]
  }
};
var textColors = {
  bold: {
    default: ['inverse', _colors.N0],
    inprogress: ['inverse', _colors.N0],
    moved: ['warning.inverse', _colors.N800],
    new: ['inverse', _colors.N0],
    removed: ['inverse', _colors.N0],
    success: ['inverse', _colors.N0]
  },
  subtle: {
    default: ['color.text', _colors.N500],
    inprogress: ['information', _colors.B500],
    moved: ['warning', _colors.N800],
    new: ['discovery', _colors.P500],
    removed: ['danger', _colors.R500],
    success: ['success', _colors.G500]
  }
};