/* eslint-disable @atlaskit/design-system/ensure-design-token-usage */

/** @jsx jsx */
import { memo } from 'react';
import { jsx } from '@emotion/core';
import { UNSAFE_Box as Box, UNSAFE_SPACING_SCALE as SPACING_SCALE, UNSAFE_Text as Text } from '@atlaskit/ds-explorations';
import { B400, B50, B500, G400, G50, G500, N0, N40, N500, N800, P400, P50, P500, R400, R50, R500, Y500, Y75 } from '@atlaskit/theme/colors';

/**
 * __Lozenge__
 *
 * A lozenge is a visual indicator used to highlight an item's status for quick recognition.
 *
 * - [Examples](https://atlassian.design/components/lozenge/examples)
 * - [Code](https://atlassian.design/components/lozenge/code)
 * - [Usage](https://atlassian.design/components/lozenge/usage)
 */
var Lozenge = /*#__PURE__*/memo(function (_ref) {
  var children = _ref.children,
      testId = _ref.testId,
      _ref$isBold = _ref.isBold,
      isBold = _ref$isBold === void 0 ? false : _ref$isBold,
      _ref$appearance = _ref.appearance,
      appearance = _ref$appearance === void 0 ? 'default' : _ref$appearance,
      _ref$maxWidth = _ref.maxWidth,
      maxWidth = _ref$maxWidth === void 0 ? 200 : _ref$maxWidth,
      _ref$style = _ref.style,
      style = _ref$style === void 0 ? {} : _ref$style;
  var appearanceStyle = isBold ? 'bold' : 'subtle';
  var appearanceType = appearance in backgroundColors[appearanceStyle] ? appearance : 'default';
  var maxWidthValue = typeof maxWidth === 'string' ? maxWidth : "".concat(maxWidth, "px");
  return jsx(Box, {
    as: "span",
    display: "inlineFlex",
    backgroundColor: backgroundColors[appearanceStyle][appearanceType],
    borderRadius: "normal",
    paddingInline: "sp-50",
    position: "static",
    testId: testId,
    UNSAFE_style: {
      backgroundColor: style.backgroundColor,
      verticalAlign: 'baseline',
      maxWidth: '100%'
    }
  }, jsx(Text, {
    as: "span",
    fontSize: "11px",
    fontWeight: "700",
    lineHeight: "16px",
    textTransform: "uppercase",
    color: textColors[appearanceStyle][appearanceType],
    shouldTruncate: true,
    UNSAFE_style: {
      color: style.color,
      width: '100%',
      maxWidth: "calc(".concat(maxWidthValue, " - ").concat(SPACING_SCALE['sp-100'], "px)") // to negate paddingInline specified on Box above

    },
    testId: testId && "".concat(testId, "--text")
  }, children));
});
Lozenge.displayName = 'Lozenge';
export default Lozenge; // Lozenge colors

var backgroundColors = {
  bold: {
    default: ['neutral.bold', N500],
    inprogress: ['information.bold', B400],
    moved: ['warning.bold', Y500],
    new: ['discovery.bold', P400],
    removed: ['danger.bold', R400],
    success: ['success.bold', G400]
  },
  subtle: {
    default: ['neutral', N40],
    inprogress: ['information', B50],
    moved: ['warning', Y75],
    new: ['discovery', P50],
    removed: ['danger', R50],
    success: ['success', G50]
  }
};
var textColors = {
  bold: {
    default: ['inverse', N0],
    inprogress: ['inverse', N0],
    moved: ['warning.inverse', N800],
    new: ['inverse', N0],
    removed: ['inverse', N0],
    success: ['inverse', N0]
  },
  subtle: {
    default: ['color.text', N500],
    inprogress: ['information', B500],
    moved: ['warning', N800],
    new: ['discovery', P500],
    removed: ['danger', R500],
    success: ['success', G500]
  }
};